USE SevenSteps;
GO

/* =================================================== */
/* Problem: Find first and last DueDate for all orders */
/*          that were ordered after date X.            */
/* =================================================== */

-- (Same problem as previous demo - same solution)
DECLARE @StartTime datetime2;
SET @StartTime = SYSDATETIME();

SELECT MIN(DueDate), MAX(DueDate)
FROM   dbo.SalesOrderHeader
WHERE  OrderDate >= '20070730';
--WHERE  OrderDate >= '20110730';

SELECT DATEDIFF(ms, @StartTime, SYSDATETIME()) AS "Elapsed time (ms)";
GO



-- INCLUDE DueDate to existing index - this makes it a covering index
-- (Unfortunately, this can only be done by dropping and recreating the index)
DROP INDEX dbo.SalesOrderHeader.ix_SalesOrderHeader_OrderDate;
GO
CREATE INDEX    ix_SalesOrderHeader_OrderDate
       ON       dbo.SalesOrderHeader(OrderDate)
       INCLUDE (DueDate);
GO

DECLARE @StartTime datetime2;
SET @StartTime = SYSDATETIME();

SELECT MIN(DueDate), MAX(DueDate)
FROM   dbo.SalesOrderHeader
WHERE  OrderDate >= '20070730';
--WHERE  OrderDate >= '20110730';

SELECT DATEDIFF(ms, @StartTime, SYSDATETIME()) AS "Elapsed time (ms)";
GO




-- Bonus: In this specific case, the covering index now enables a plan
--        that is optimal for all cases - this solves the parameter sniffing issue!

-- Execution plan determined in first call, then reused for next call
DECLARE @StartTime datetime2;
SET @StartTime = SYSDATETIME();

EXEC dbo.MinMaxDueDate '20070730';
--EXEC dbo.MinMaxDueDate '20110730';

SELECT DATEDIFF(ms, @StartTime, SYSDATETIME()) AS "Elapsed time (ms)";
go

-- Forceer leegmaken van de procedure cache
DBCC FREEPROCCACHE;
go
